var group__spa__utils =
[
    [ "spa_rectangle", "structspa__rectangle.html", [
      [ "height", "structspa__rectangle.html#a7510157f1ac054a3dc70c0c6d49083ad", null ],
      [ "width", "structspa__rectangle.html#a6104eab08e11a0f5f658a5ffd1878068", null ]
    ] ],
    [ "spa_point", "structspa__point.html", [
      [ "x", "structspa__point.html#ad0e2590c913f99dd1bd9f18aecffc951", null ],
      [ "y", "structspa__point.html#a4e7f622b7e262885081e0459bafc22eb", null ]
    ] ],
    [ "spa_region", "structspa__region.html", [
      [ "position", "structspa__region.html#a848acf4be0e186e985eafc3b858f0079", null ],
      [ "size", "structspa__region.html#aac81486ee3a2fbbd52534691bc740f63", null ]
    ] ],
    [ "spa_fraction", "structspa__fraction.html", [
      [ "denom", "structspa__fraction.html#af099fb3a18c93ddac10239564da9de0c", null ],
      [ "num", "structspa__fraction.html#a55246db96d647cd96be18983d59feb56", null ]
    ] ],
    [ "spa_dict_item", "structspa__dict__item.html", [
      [ "key", "structspa__dict__item.html#a16dc8153e2ea77c9c82380456734478a", null ],
      [ "value", "structspa__dict__item.html#af08479e3ff870039be002b436a02457d", null ]
    ] ],
    [ "spa_dict", "structspa__dict.html", [
      [ "flags", "structspa__dict.html#a88aca003fcdbc47599ffb3e2737f1a69", null ],
      [ "items", "structspa__dict.html#a1f1083da3fcd51b9c3eb22cc8f1d54e0", null ],
      [ "n_items", "structspa__dict.html#a3b3b78bfe5fffe13a10720bb7099c399", null ]
    ] ],
    [ "spa_list", "structspa__list.html", [
      [ "next", "structspa__list.html#aed4aa24d6a3d4f62a4198296312a6196", null ],
      [ "prev", "structspa__list.html#ab67df98c96319f199a02cb48ee7de93e", null ]
    ] ],
    [ "spa_ringbuffer", "structspa__ringbuffer.html", [
      [ "readindex", "structspa__ringbuffer.html#a6374bbe98fbea037a4479f11cec464c2", null ],
      [ "writeindex", "structspa__ringbuffer.html#ae7b07eebf6c9f8d3266f46cdffdfca28", null ]
    ] ],
    [ "SPA_ALIGNED", "group__spa__utils.html#gac894bd2d39b2644e1bacf4b11c0a187d", null ],
    [ "SPA_ANSI_BG_BLACK", "group__spa__utils.html#ga0946c36737a6380393f347e11a344f62", null ],
    [ "SPA_ANSI_BG_BLUE", "group__spa__utils.html#ga9691e3321fd9a291860a04b0d219d52f", null ],
    [ "SPA_ANSI_BG_BRIGHT_BLACK", "group__spa__utils.html#ga45969961d88b3eb738a703cd42cac963", null ],
    [ "SPA_ANSI_BG_BRIGHT_BLUE", "group__spa__utils.html#ga4e4c73b12e79a492d93d1697cb8d48bb", null ],
    [ "SPA_ANSI_BG_BRIGHT_CYAN", "group__spa__utils.html#gafddf179b8a30fe15781f37221f450901", null ],
    [ "SPA_ANSI_BG_BRIGHT_GREEN", "group__spa__utils.html#gab2d591c87fb435e76e453d03be99df8f", null ],
    [ "SPA_ANSI_BG_BRIGHT_MAGENTA", "group__spa__utils.html#ga30bf9737c83cb4ba243c94a59a119194", null ],
    [ "SPA_ANSI_BG_BRIGHT_RED", "group__spa__utils.html#gaa1a2ac28f17e74bb15ca4c4110c65dd5", null ],
    [ "SPA_ANSI_BG_BRIGHT_WHITE", "group__spa__utils.html#ga82142b091ace82f6742527d72cb3a9e4", null ],
    [ "SPA_ANSI_BG_BRIGHT_YELLOW", "group__spa__utils.html#ga23fb4150d520f1352f62d4c23665611e", null ],
    [ "SPA_ANSI_BG_CYAN", "group__spa__utils.html#ga1470418d06e2a7bd7827d381f6f65ec9", null ],
    [ "SPA_ANSI_BG_GREEN", "group__spa__utils.html#gaeb6b06daa60ace33973cba3c2a1e448f", null ],
    [ "SPA_ANSI_BG_MAGENTA", "group__spa__utils.html#ga5dafdd57666d36a3a23172b309e5e2d8", null ],
    [ "SPA_ANSI_BG_RED", "group__spa__utils.html#ga678d0b293b16e0d6a1fe0acef4915d58", null ],
    [ "SPA_ANSI_BG_WHITE", "group__spa__utils.html#ga26068a6856bb80d861b93c4610702149", null ],
    [ "SPA_ANSI_BG_YELLOW", "group__spa__utils.html#gaf9bb5e8b669e7d5f3bfe852b8cb936e3", null ],
    [ "SPA_ANSI_BLACK", "group__spa__utils.html#ga81bfa95fac68a133fd545e7fa4e9d1d1", null ],
    [ "SPA_ANSI_BLUE", "group__spa__utils.html#ga400ba03121c36fd42526652f8aa2842e", null ],
    [ "SPA_ANSI_BOLD", "group__spa__utils.html#gad9ac3e26ccd0b443d1dcfcbbb6222b3e", null ],
    [ "SPA_ANSI_BOLD_BLACK", "group__spa__utils.html#gaf4a26af34064708378165994008fc927", null ],
    [ "SPA_ANSI_BOLD_BLUE", "group__spa__utils.html#gab904421bf8255a770bfc02ea7262ef19", null ],
    [ "SPA_ANSI_BOLD_CYAN", "group__spa__utils.html#gaf63c55041d8c8bd7b319645c7f58a9d4", null ],
    [ "SPA_ANSI_BOLD_GREEN", "group__spa__utils.html#ga1ad5a1f13b842231b40b939664be8a1b", null ],
    [ "SPA_ANSI_BOLD_MAGENTA", "group__spa__utils.html#gaff1dc44edfa13989eee97021878fef42", null ],
    [ "SPA_ANSI_BOLD_RED", "group__spa__utils.html#gae27024e6cb0c01d10bca2b1aaed33d60", null ],
    [ "SPA_ANSI_BOLD_WHITE", "group__spa__utils.html#gaef43ee57bc72517c30237843d256fabc", null ],
    [ "SPA_ANSI_BOLD_YELLOW", "group__spa__utils.html#gabcf2363d262cee0526346177c9246c92", null ],
    [ "SPA_ANSI_BRIGHT_BLACK", "group__spa__utils.html#ga7e7da142af610c73f650312677383d99", null ],
    [ "SPA_ANSI_BRIGHT_BLUE", "group__spa__utils.html#ga175c38f8abfe98a985d818f19398a1ae", null ],
    [ "SPA_ANSI_BRIGHT_CYAN", "group__spa__utils.html#ga8b943fd646e64cbd0fa60484a0900d94", null ],
    [ "SPA_ANSI_BRIGHT_GREEN", "group__spa__utils.html#ga345172ae350c8874916593637183e205", null ],
    [ "SPA_ANSI_BRIGHT_MAGENTA", "group__spa__utils.html#ga4921f428347162b6e1afd0d5362370ec", null ],
    [ "SPA_ANSI_BRIGHT_RED", "group__spa__utils.html#ga0e4c8983931daa2280bb0271dc6f5e66", null ],
    [ "SPA_ANSI_BRIGHT_WHITE", "group__spa__utils.html#ga1dc9444a7f044257277d8c00d4ad665e", null ],
    [ "SPA_ANSI_BRIGHT_YELLOW", "group__spa__utils.html#gaf5d7fe4c5b226f604c8a0fa0c5c698d0", null ],
    [ "SPA_ANSI_CYAN", "group__spa__utils.html#ga9729d30d15a0ab085f74de854ec68baa", null ],
    [ "SPA_ANSI_DARK_BLACK", "group__spa__utils.html#gad05b2989634f1bdd58adce5724527574", null ],
    [ "SPA_ANSI_DARK_BLUE", "group__spa__utils.html#ga1454d578034f980cbb9f6980f73da335", null ],
    [ "SPA_ANSI_DARK_CYAN", "group__spa__utils.html#gafd4422262a79ffe4c757457a574e962e", null ],
    [ "SPA_ANSI_DARK_GREEN", "group__spa__utils.html#ga5d126113edfe9df70eb7f68a6f874c85", null ],
    [ "SPA_ANSI_DARK_MAGENTA", "group__spa__utils.html#ga264f4f72d5368389307b91f42c0a734a", null ],
    [ "SPA_ANSI_DARK_RED", "group__spa__utils.html#ga5107dd7b42a3abdcd2cbf1623f5a76af", null ],
    [ "SPA_ANSI_DARK_WHITE", "group__spa__utils.html#ga67b64705e0973206f62671580235ad91", null ],
    [ "SPA_ANSI_DARK_YELLOW", "group__spa__utils.html#gacc92b4eb940bdf521a96b02f0261fb6d", null ],
    [ "SPA_ANSI_GREEN", "group__spa__utils.html#gac75fc46d7948111d087d9dd444cbcb6e", null ],
    [ "SPA_ANSI_ITALIC", "group__spa__utils.html#ga9eeac089fc2d7d519af0c3393b16c288", null ],
    [ "SPA_ANSI_MAGENTA", "group__spa__utils.html#gace360eddb3a5fca36e9a3730606f6fad", null ],
    [ "SPA_ANSI_RED", "group__spa__utils.html#gab2f81c97caf8615cf3d9399aec7ee601", null ],
    [ "SPA_ANSI_RESET", "group__spa__utils.html#ga54d15ab61e76cc597c18301ff384435e", null ],
    [ "SPA_ANSI_UNDERLINE", "group__spa__utils.html#gaad15091a1f40cc819dff1fc80374cc34", null ],
    [ "SPA_ANSI_WHITE", "group__spa__utils.html#ga8dcc1e4283933e216eca2305dda3ccf6", null ],
    [ "SPA_ANSI_YELLOW", "group__spa__utils.html#gaa8e085e38fa2f989abeccfeef670fe54", null ],
    [ "spa_aprintf", "group__spa__utils.html#ga007f98725701a4b6debe365c7a5e0bbe", null ],
    [ "spa_assert", "group__spa__utils.html#gafa109f3532687323c8f8340f18a15220", null ],
    [ "spa_assert_not_reached", "group__spa__utils.html#ga6212956dcff36c69fa954f66efaefbcf", null ],
    [ "spa_assert_se", "group__spa__utils.html#ga48e64fde9ece326caf683b04597614a5", null ],
    [ "SPA_ASYNC_BIT", "group__spa__utils.html#gab20d44383dc08a6c9f29126c9ff54a7d", null ],
    [ "SPA_ASYNC_MASK", "group__spa__utils.html#ga983f495e5784eb226844b4f540d8dfad", null ],
    [ "SPA_ASYNC_SEQ_MASK", "group__spa__utils.html#ga90c70217108ef23c77b3a3f336fab491", null ],
    [ "SPA_CLAMP", "group__spa__utils.html#ga33e30c1bdbba747c8c00077913d48411", null ],
    [ "SPA_CONTAINER_OF", "group__spa__utils.html#gaa495b586c261831b67f09c7f9851aa05", null ],
    [ "SPA_DEPRECATED", "group__spa__utils.html#ga933e7dba5e09dd618617b7b16c0d42fc", null ],
    [ "spa_dict_for_each", "group__spa__utils.html#gadacdfca3f982645e9671b030fb8e6568", null ],
    [ "SPA_DICT_INIT", "group__spa__utils.html#gacba99b7769fe7dde36f2157eb622a9ac", null ],
    [ "SPA_DICT_INIT_ARRAY", "group__spa__utils.html#ga892ec66ef5891b9d84e403ab815356bf", null ],
    [ "SPA_DICT_ITEM_INIT", "group__spa__utils.html#ga2f4c23f6a5dd5c9eb93cfeccb8211901", null ],
    [ "SPA_DIRECTION_REVERSE", "group__spa__utils.html#ga57aec3d89182594c8fef7be284f41fff", null ],
    [ "SPA_EXPORT", "group__spa__utils.html#gac1ac8f034b73e453c531d928cdfdd8b7", null ],
    [ "SPA_FALLTHROUGH", "group__spa__utils.html#gacbdd2b8d9e9137bbbd9a38f495c80263", null ],
    [ "SPA_FLAG_CLEAR", "group__spa__utils.html#gaceee1eb1469c2ab68034f5619913bc0d", null ],
    [ "SPA_FLAG_IS_SET", "group__spa__utils.html#gaa44a69e371d934ab026ae08af1d9b67e", null ],
    [ "SPA_FLAG_MASK", "group__spa__utils.html#gaf296ce57d6de2645675d2c89fdc8af0a", null ],
    [ "SPA_FLAG_SET", "group__spa__utils.html#ga006941b3f6423cec7b170b4434d8a799", null ],
    [ "SPA_FLAG_UPDATE", "group__spa__utils.html#ga3bca1a11d1c7e8404f9456580acf0676", null ],
    [ "SPA_FOR_EACH_ELEMENT", "group__spa__utils.html#ga895eccfd8032e0e9eec102e3b8442f12", null ],
    [ "SPA_FRACTION", "group__spa__utils.html#ga58dddf4d57e29beade3b44e156dea532", null ],
    [ "SPA_ID_INVALID", "group__spa__utils.html#ga6c3f9f95123f53da37d2bd173bd17ed1", null ],
    [ "SPA_IDX_INVALID", "group__spa__utils.html#gaabdb5fd45bca56878896d7c28204fb88", null ],
    [ "SPA_INT_TO_PTR", "group__spa__utils.html#gafa5449ce6a2352b7966fa923892a46fa", null ],
    [ "SPA_IS_ALIGNED", "group__spa__utils.html#gab4c957beedd4012fd0513f174d7b8b1a", null ],
    [ "SPA_LIKELY", "group__spa__utils.html#ga9a615b131c891caac9a73e05b35da09c", null ],
    [ "spa_list_append", "group__spa__utils.html#gadc766e382f0a0594ad4615fbc5fc7751", null ],
    [ "spa_list_consume", "group__spa__utils.html#ga60b0fbabb70671c71d40e5443f6489d8", null ],
    [ "spa_list_cursor_end", "group__spa__utils.html#ga26b91db2741857b5402dbc6ec0cd7857", null ],
    [ "spa_list_cursor_start", "group__spa__utils.html#gaadec436f232586998917c75efeac05ab", null ],
    [ "spa_list_first", "group__spa__utils.html#ga94381f31e216abb3a54a9c8866318818", null ],
    [ "spa_list_for_each", "group__spa__utils.html#gac75faa4587e0df7c11f10b3d44590a7d", null ],
    [ "spa_list_for_each_cursor", "group__spa__utils.html#ga75add8c86fa73d438fdfc3568062bb45", null ],
    [ "spa_list_for_each_next", "group__spa__utils.html#ga45afc4b42dfaa194a4675532338fc621", null ],
    [ "spa_list_for_each_prev", "group__spa__utils.html#ga49f1884c56d222f6e7d68e437728366a", null ],
    [ "spa_list_for_each_reverse", "group__spa__utils.html#ga2b8d65766f4dfe2a009073a3ed3a8edb", null ],
    [ "spa_list_for_each_safe", "group__spa__utils.html#gadea44c074f21f2a8c15825e526110bf0", null ],
    [ "spa_list_for_each_safe_next", "group__spa__utils.html#gab5c2aa1c10907d6fe58ff398764344f6", null ],
    [ "spa_list_for_each_safe_prev", "group__spa__utils.html#ga964734871c9792e189ce23a08b74c4d0", null ],
    [ "spa_list_for_each_safe_reverse", "group__spa__utils.html#gae1826e761b00fde76907589f66cf74a9", null ],
    [ "SPA_LIST_INIT", "group__spa__utils.html#gacc823f4d4d5c7fa8ee8ef00a56c0a8ec", null ],
    [ "spa_list_is_empty", "group__spa__utils.html#gabb88430b81aa5bb148fb4054da84c37e", null ],
    [ "spa_list_is_end", "group__spa__utils.html#ga1cc2697f03626118318c1506bed70767", null ],
    [ "spa_list_last", "group__spa__utils.html#gaf76607bd5d48aa7b41d693260a19b68e", null ],
    [ "spa_list_next", "group__spa__utils.html#ga108cc4dbe3573f71ac8fa0e6d54b8dac", null ],
    [ "spa_list_prepend", "group__spa__utils.html#gab7f00cc70bccbe6b99fba699905757dc", null ],
    [ "spa_list_prev", "group__spa__utils.html#ga587a1750ebac2e8f980228db27b44e0f", null ],
    [ "SPA_MAX", "group__spa__utils.html#gafd41067bab5e0c66b38886f672702dd4", null ],
    [ "SPA_MEMBER", "group__spa__utils.html#gaad6949f0b0a59d29fdf35ff11ebf83cb", null ],
    [ "SPA_MEMBER_ALIGN", "group__spa__utils.html#ga5e46f399b745cda80c6a5a8ab8d5d14f", null ],
    [ "spa_memcpy", "group__spa__utils.html#gadd03b1b1f299d9249de66ff32bc34569", null ],
    [ "spa_memmove", "group__spa__utils.html#gaf7a3ad1f0f015a14f7719022fc6e5a0e", null ],
    [ "spa_memzero", "group__spa__utils.html#gae2c26bfcbc2a33bcfae86018b35fab20", null ],
    [ "SPA_MIN", "group__spa__utils.html#ga06647c110a0382a09bea681a14634f64", null ],
    [ "SPA_MSEC_PER_SEC", "group__spa__utils.html#gacc9914448bc9fd68ae5ccf004c401bcb", null ],
    [ "SPA_N_ELEMENTS", "group__spa__utils.html#ga796e3d4570d8d539ea5886074a646a11", null ],
    [ "spa_nop", "group__spa__utils.html#gae8d35b670e70b6cdba489ca76b5791d4", null ],
    [ "SPA_NORETURN", "group__spa__utils.html#ga01ba22304e834c86556e645614f65d84", null ],
    [ "SPA_NSEC_PER_MSEC", "group__spa__utils.html#ga6259b69a24b203050fe69cacac57748a", null ],
    [ "SPA_NSEC_PER_SEC", "group__spa__utils.html#ga7b3174639eb92d4c045a2bbc72a035df", null ],
    [ "SPA_NSEC_PER_USEC", "group__spa__utils.html#ga6c2a22d6e106ac2f2d69d66a8ed35bd0", null ],
    [ "SPA_POINT", "group__spa__utils.html#gaf42b2cfc208dc17d25624d84f962b25d", null ],
    [ "SPA_PRINTF_FUNC", "group__spa__utils.html#gab30712bed8289c9218eb66d9bfeeab78", null ],
    [ "SPA_PTR_ALIGN", "group__spa__utils.html#ga4a50fbd4b694e2826233b6d54ef3b5a8", null ],
    [ "SPA_PTR_ALIGNMENT", "group__spa__utils.html#ga26f69327ba25a67c5120805511190740", null ],
    [ "SPA_PTR_TO_INT", "group__spa__utils.html#gac8080acabcd35c560a15df5e1801afa1", null ],
    [ "SPA_PTR_TO_UINT32", "group__spa__utils.html#gaa92b4913ce779aa401cc714ae829eace", null ],
    [ "SPA_PTRDIFF", "group__spa__utils.html#gaec22d2ead4ec1771760219dc16f24709", null ],
    [ "SPA_PTROFF", "group__spa__utils.html#gae8ab0b793d870a9725897e695454c12b", null ],
    [ "SPA_PTROFF_ALIGN", "group__spa__utils.html#ga59196e4cfb0d8c0a8bdcd909cbbea334", null ],
    [ "SPA_RECTANGLE", "group__spa__utils.html#gafdd52836cf3dfdc12328615ac44c18e0", null ],
    [ "SPA_REGION", "group__spa__utils.html#gace48f5bc6836a62c328fcac938f8ea6e", null ],
    [ "SPA_RESTRICT", "group__spa__utils.html#ga3fecbba7e4f85f539f62c8db39f12b0a", null ],
    [ "SPA_RESULT_ASYNC_SEQ", "group__spa__utils.html#ga6eb31af26e93aca850932671837ad577", null ],
    [ "SPA_RESULT_IS_ASYNC", "group__spa__utils.html#gac6610ec8c7368e5c1bf18f92018656f2", null ],
    [ "SPA_RESULT_IS_ERROR", "group__spa__utils.html#ga1f29cbb3d4dcbcde8d828dca94ebe44e", null ],
    [ "SPA_RESULT_IS_OK", "group__spa__utils.html#ga94d2e4501333b4073e27b472ba94135f", null ],
    [ "SPA_RESULT_RETURN_ASYNC", "group__spa__utils.html#ga1546730722175618f789f387e8593f35", null ],
    [ "spa_return_if_fail", "group__spa__utils.html#gaa360562916c7e9ab66865f277477f4e6", null ],
    [ "spa_return_val_if_fail", "group__spa__utils.html#ga632087e970399228667a768ba8424f4e", null ],
    [ "SPA_RINGBUFFER_INIT", "group__spa__utils.html#ga636d45b00fa064ed74316528cd21cab5", null ],
    [ "SPA_ROUND_DOWN_N", "group__spa__utils.html#gabfdffcb3a4e4e4a488a2ff714e01b3ca", null ],
    [ "SPA_ROUND_UP_N", "group__spa__utils.html#ga3404aa33acd9e8316fb33ebd146446f0", null ],
    [ "SPA_SENTINEL", "group__spa__utils.html#gad485e752b9b897f6434724f669ba72ae", null ],
    [ "spa_strerror", "group__spa__utils.html#ga93ac5a2c6bebade4a7268f61f2dc5731", null ],
    [ "SPA_STRINGIFY", "group__spa__utils.html#ga2157cfb3de1793302e5d08958bdc8ab2", null ],
    [ "SPA_STRINGIFY_1", "group__spa__utils.html#gaa3a2b836ca54d95f207f5557988db748", null ],
    [ "SPA_SWAP", "group__spa__utils.html#ga7f23cca5e034297bbd1b6860d1dbfdbc", null ],
    [ "SPA_TIME_INVALID", "group__spa__utils.html#ga1b605788d4782d77eb54b75f258413b9", null ],
    [ "SPA_TIMESPEC_TO_NSEC", "group__spa__utils.html#gad5b23b2094b330aacd6489da1c8fa7b7", null ],
    [ "SPA_TIMESPEC_TO_USEC", "group__spa__utils.html#ga3d65c899d0f8937244ed2893d1841f6f", null ],
    [ "SPA_TIMEVAL_TO_NSEC", "group__spa__utils.html#ga7b184a799c7168d95deaecab5208f557", null ],
    [ "SPA_TIMEVAL_TO_USEC", "group__spa__utils.html#gafdcbf720fb6f9ab8a91a0eacdbc3beca", null ],
    [ "SPA_TYPECHECK", "group__spa__utils.html#ga1179685eef5a041a5c8e60a9a6483048", null ],
    [ "SPA_UINT32_TO_PTR", "group__spa__utils.html#gaf8cdb131feb79dfd1d9d1097cb89c052", null ],
    [ "SPA_UNLIKELY", "group__spa__utils.html#gac30327f8b5e6a9c6f9129a73581d09dc", null ],
    [ "SPA_UNUSED", "group__spa__utils.html#ga1f57dfee056b657ddcd2bc69a7f45bce", null ],
    [ "SPA_USEC_PER_MSEC", "group__spa__utils.html#ga4a52677c41f0a787a3c6624f18647cb6", null ],
    [ "SPA_USEC_PER_SEC", "group__spa__utils.html#gaf9f1e071334f25ea8580f2509d17fcdd", null ],
    [ "spa_zero", "group__spa__utils.html#ga3625c72ccb164919faaf2a3c5a37e9c2", null ],
    [ "spa_direction", "group__spa__utils.html#ga9f2fae4a58cc2e3fdf568d1afc9dc7c1", [
      [ "SPA_DIRECTION_INPUT", "group__spa__utils.html#gga9f2fae4a58cc2e3fdf568d1afc9dc7c1a48000c4ffb67d7fcba31225d2ca9600d", null ],
      [ "SPA_DIRECTION_OUTPUT", "group__spa__utils.html#gga9f2fae4a58cc2e3fdf568d1afc9dc7c1ad27b9a94c88677dfa8681ec43abac456", null ]
    ] ],
    [ "spa_atob", "group__spa__utils.html#gab3a694d92dd8a709ab5472435e0a7564", null ],
    [ "spa_atod", "group__spa__utils.html#ga33cdf7a302f3c85ac543eb9ec93e46e8", null ],
    [ "spa_atof", "group__spa__utils.html#ga67e8e1c756e642c17ba68d0c1f4d5e00", null ],
    [ "spa_atoi32", "group__spa__utils.html#ga072ed7e1f33bae16b52b6919be07afdb", null ],
    [ "spa_atoi64", "group__spa__utils.html#gafd8f9f01785a8e06e56987f4481d6881", null ],
    [ "spa_atou32", "group__spa__utils.html#ga3fda42560feb3f2bc15535ee4036af5b", null ],
    [ "spa_atou64", "group__spa__utils.html#gaf89b855098162f17c1c52e4c42ad4607", null ],
    [ "spa_dict_item_compare", "group__spa__utils.html#gae61728b6f242a97e58dd08e6a8bdcd4d", null ],
    [ "spa_dict_lookup", "group__spa__utils.html#ga9217453380db3a5ee2fc0982bba9a7b7", null ],
    [ "spa_dict_lookup_item", "group__spa__utils.html#ga8716936c7835d176e726fb0b96dcbd2f", null ],
    [ "spa_dict_qsort", "group__spa__utils.html#ga8efaa572829cfe733f35f3f733d4f6fa", null ],
    [ "spa_list_init", "group__spa__utils.html#ga20f9161c0f0f531db3d3741c3fe7191c", null ],
    [ "spa_list_insert", "group__spa__utils.html#gaf23a4f82a74bd5a81e7fb898a909c611", null ],
    [ "spa_list_insert_list", "group__spa__utils.html#ga4075e12deaec8b25f38b09f074341c5c", null ],
    [ "spa_list_remove", "group__spa__utils.html#ga8af5eeb723aad9353c22be7e9bcc3274", null ],
    [ "spa_ringbuffer_get_read_index", "group__spa__utils.html#gaafdd9698d29909e23e34427c02cfd023", null ],
    [ "spa_ringbuffer_get_write_index", "group__spa__utils.html#gad47f541160d0ad22e6fcaf1bffb3cf0e", null ],
    [ "spa_ringbuffer_init", "group__spa__utils.html#gac3185d863ed1edff545c8091e745daec", null ],
    [ "spa_ringbuffer_read_data", "group__spa__utils.html#gaa1a1f64dc2717429854130fde4b48364", null ],
    [ "spa_ringbuffer_read_update", "group__spa__utils.html#ga3148e0c073243e1597aad06b29f3b5b5", null ],
    [ "spa_ringbuffer_set_avail", "group__spa__utils.html#gad1603a8df0421a028027c45b3d753856", null ],
    [ "spa_ringbuffer_write_data", "group__spa__utils.html#ga2326c5aa37b3bd9e3473beb06395e786", null ],
    [ "spa_ringbuffer_write_update", "group__spa__utils.html#gadf0f7d4be854e463753cd082f82c18b9", null ],
    [ "spa_scnprintf", "group__spa__utils.html#ga0c8bfe9776d2357cc87f56fcfeb56ce6", null ],
    [ "spa_strendswith", "group__spa__utils.html#ga89163c63fdbf362008c4215aa4c30b32", null ],
    [ "spa_streq", "group__spa__utils.html#ga3bacdbb55417881c16b6c9be7113cd35", null ],
    [ "spa_strneq", "group__spa__utils.html#ga1b7fac98c4422b0945f1829243567414", null ],
    [ "spa_strstartswith", "group__spa__utils.html#ga67168486cf1067d2f0a33c1437545d0e", null ],
    [ "spa_vscnprintf", "group__spa__utils.html#ga4d59eb3327dc1b56652b0549eb440163", null ]
];